@@ -20,13 +20,16 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 #include <glib.h>
 #include "glibintl.h"
 
 #include "ginputstream.h"
 #include "gseekable.h"
+#include "gcancellable.h"
+#include "gasyncresult.h"
 #include "gsimpleasyncresult.h"
+#include "gioerror.h"
 
 #include "gioalias.h"
 
@@ -89,8 +92,7 @@ g_input_stream_finalize (GObject *object)
   if (!stream->priv->closed)
     g_input_stream_close (stream, NULL, NULL);
 
-  if (G_OBJECT_CLASS (g_input_stream_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_input_stream_parent_class)->finalize) (object);
+  G_OBJECT_CLASS (g_input_stream_parent_class)->finalize (object);
 }
 
 static void
@@ -102,9 +104,8 @@ g_input_stream_dispose (GObject *object)
   
   if (!stream->priv->closed)
     g_input_stream_close (stream, NULL, NULL);
-  
-  if (G_OBJECT_CLASS (g_input_stream_parent_class)->dispose)
-    (*G_OBJECT_CLASS (g_input_stream_parent_class)->dispose) (object);
+
+  G_OBJECT_CLASS (g_input_stream_parent_class)->dispose (object);
 }
 
 
@@ -191,8 +192,8 @@ g_input_stream_read  (GInputStream  *stream,
 
   if (class->read_fn == NULL) 
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-		   _("Input stream doesn't implement read"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+                           _("Input stream doesn't implement read"));
       return -1;
     }
 
@@ -414,7 +415,7 @@ g_input_stream_real_skip (GInputStream  *stream,
  *
  * On failure the first error that happened will be reported, but the close
  * operation will finish as much as possible. A stream that failed to
- * close will still return %G_IO_ERROR_CLOSED all operations. Still, it
+ * close will still return %G_IO_ERROR_CLOSED for all operations. Still, it
  * is important to check and report the error to the user.
  *
  * If @cancellable is not NULL, then the operation can be cancelled by
@@ -890,14 +891,14 @@ g_input_stream_set_pending (GInputStream *stream, GError **error)
   
   if (stream->priv->closed)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_CLOSED,
-		   _("Stream is already closed"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_CLOSED,
+                           _("Stream is already closed"));
       return FALSE;
     }
   
   if (stream->priv->pending)
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_PENDING,
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_PENDING,
 		/* Translators: This is an error you get if there is already an
 		 * operation running against this stream when you try to start
 		 * one */
